# API Reference

```{eval-rst}
.. autoclass:: selprotopy.client.base.SELClient
   :members:
```


# Sub-Modules and Other Package API References

```{eval-rst}
.. toctree::
   :maxdepth: 1
   
   exceptions
```